@@ -96,7 +96,7 @@ class _WiserRoom(object):
     @property
     def current_temperature(self) -> float:
         """Get current temperature of the room"""
-        return tf._from_wiser_temp(self._data.get("CalculatedTemperature", TEMP_MINIMUM))
+        return tf._from_wiser_temp(self._data.get("CalculatedTemperature", TEMP_MINIMUM), "current")
 
     @property
     def current_humidity(self) -> int:
@@ -231,6 +231,11 @@ class _WiserRoom(object):
         """Get the percentage demand of the room"""
         return self._data.get("PercentageDemand", 0)
 
+    @property
+    def roomstat_id(self) -> int:
+        """Get the id of the roomstat"""
+        return self._data.get("RoomStatId", None)
+
     @property
     def schedule(self) -> _WiserSchedule:
         """Get the schedule for the room"""
@@ -256,6 +261,16 @@ class _WiserRoom(object):
         """Get the origin of the target temperature setting for the room"""
         return self._data.get("SetpointOrigin", self._data.get("SetpointOrigin", TEXT_UNKNOWN))
 
+    @property
+    def underfloor_heating_id(self) -> int:
+        """Get the id of the underfloor heating controller"""
+        return self._data.get("UnderFloorHeatingId", None)
+
+    @property
+    def underfloor_heating_relay_ids(self) -> int:
+        """Get the id of the underfloor heating controller relay ids"""
+        return sorted(self._data.get("UfhRelayIds", []))
+
     @property
     def window_detection_active(self) -> bool:
         """Get or set if window detection is active"""
