@@ -48,7 +48,7 @@ from .hot_water import _WiserHotwater
 from .moments import _WiserMomentCollection
 from .rest_controller import _WiserRestController, _WiserConnection
 from .room import _WiserRoomCollection
-from .schedule import _WiserScheduleCollection
+from .schedule import _WiserScheduleCollection, WiserScheduleType
 from .system import _WiserSystem
 
 
@@ -104,20 +104,20 @@ class WiserAPI(object):
             # Schedules Collection
             self._schedules = _WiserScheduleCollection(self._wiser_rest_controller, _schedule_data)
 
-            # Devices Collection
-            self._devices = _WiserDeviceCollection(self._wiser_rest_controller, _domain_data, self._schedules )
-
             # System Object
             _device_data = _domain_data.get("Device", [])
             self._system = _WiserSystem(self._wiser_rest_controller, _domain_data, _network_data, _device_data)
 
+            # Devices Collection
+            self._devices = _WiserDeviceCollection(self._wiser_rest_controller, _domain_data, self._schedules )
+
             # Rooms Collection
             room_data = _domain_data.get("Room", [])
-            self._rooms = _WiserRoomCollection(self._wiser_rest_controller, room_data, self._schedules, self._devices)
+            self._rooms = _WiserRoomCollection(self._wiser_rest_controller, room_data, self._schedules.get_by_type(WiserScheduleType.heating), self._devices)
 
             # Hot Water
             if _domain_data.get("HotWater"):
-                schedule = self._schedules.get_by_id(_domain_data.get("HotWater")[0].get("ScheduleId", 0))
+                schedule = self._schedules.get_by_id(WiserScheduleType.onoff, _domain_data.get("HotWater")[0].get("ScheduleId", 0))
                 self._hotwater = _WiserHotwater(
                     self._wiser_rest_controller,
                     _domain_data.get("HotWater", {})[0],
@@ -167,6 +167,11 @@ class WiserAPI(object):
         """List of room entities configured on the Wiser Hub"""
         return self._rooms
 
+    @property
+    def schedules(self):
+        """List of schedules"""
+        return self._schedules
+
     @property
     def system(self):
         """Entity of the Wiser Hub"""
